@@ -27,8 +27,8 @@ class TestLuaRuntime(unittest.TestCase):
     def test_eval(self):
         self.assertEqual(2, self.lua.eval('1+1'))
 
-    def test_run(self):
-        self.assertEqual(2, self.lua.run('return 1+1'))
+    def test_execute(self):
+        self.assertEqual(2, self.lua.execute('return 1+1'))
 
     def test_function(self):
         function = self.lua.eval('function() return 1+1 end')
@@ -46,7 +46,7 @@ class TestLuaRuntime(unittest.TestCase):
         self.assertEqual(1, function1())
 
     def test_recursive_function(self):
-        fac = self.lua.run('''\
+        fac = self.lua.execute('''\
         function fac(i)
             if i <= 1
                 then return 1
@@ -69,7 +69,7 @@ class TestLuaRuntime(unittest.TestCase):
         end
         return calc
         '''
-        calc = self.lua.run(func_code)
+        calc = self.lua.execute(func_code)
         self.assertNotEqual(None, calc)
         self.assertEqual(3,     calc(3))
         self.assertEqual(109,   calc(10))
@@ -88,7 +88,7 @@ class TestLuaRuntime(unittest.TestCase):
         def pycallback(i):
             return i**2
 
-        calc = self.lua.run(func_code)
+        calc = self.lua.execute(func_code)
 
         self.assertNotEqual(None, calc)
         self.assertEqual(12,     calc(pycallback, 3))
@@ -123,6 +123,10 @@ class TestLuaRuntime(unittest.TestCase):
         self.assertEqual(2, eval('1+1'))
         self.assertEqual(2, self.lua.eval('python.eval("1+1")'))
 
+    def test_len_table(self):
+        table = self.lua.eval('{1,2,3,4,5}')
+        self.assertEqual(5, len(table))
+
     def test_iter_table(self):
         table = self.lua.eval('{1,2,3,4,5}')
         self.assertEqual([1,2,3,4,5], list(table))
@@ -164,7 +168,11 @@ class TestLuaRuntime(unittest.TestCase):
         table = self.lua.eval('{%s}' % ','.join(['%s=%d' % (c,i) for i,c in enumerate(keys)]))
         l = list(table.items())
         l.sort()
-        self.assertEqual(zip(keys,range(len('abcdefg'))), l)
+        self.assertEqual(zip(keys,range(len(keys))), l)
+
+    def test_error_iter_function(self):
+        func = self.lua.eval('function() return 1 end')
+        self.assertRaises(TypeError, list, func)
 
     def test_string_values(self):
         function = self.lua.eval('function(s) return s .. "abc" end')
@@ -186,6 +194,10 @@ class TestLuaRuntime(unittest.TestCase):
         stringlib = self.lua.eval('string')
         self.assertEqual('abc', stringlib.lower('ABC'))
 
+    def test_getitem(self):
+        stringlib = self.lua.eval('string')
+        self.assertEqual('abc', stringlib['lower']('ABC'))
+
     def test_getattr_table(self):
         table = self.lua.eval('{ const={ name="Pi", value=3.1415927 }, const2={ name="light speed", value=3e8 }, val=1 }')
         self.assertEqual(1, table.val)
@@ -193,6 +205,58 @@ class TestLuaRuntime(unittest.TestCase):
         self.assertEqual('light speed', table.const2.name)
         self.assertEqual(3e8, table.const2.value)
 
+    def test_getitem_table(self):
+        table = self.lua.eval('{ const={ name="Pi", value=3.1415927 }, const2={ name="light speed", value=3e8 }, val=1 }')
+        self.assertEqual(1, table['val'])
+        self.assertEqual('Pi', table['const']['name'])
+        self.assertEqual('light speed', table['const2']['name'])
+        self.assertEqual(3e8, table['const2']['value'])
+
+    def test_setattr_table(self):
+        table = self.lua.eval('{ const={ name="Pi", value=3.1415927 }, const2={ name="light speed", value=3e8 }, val=1 }')
+
+        self.assertEqual(1, table.val)
+        table.val = 2
+        self.assertEqual(2, table.val)
+
+        self.assertEqual('Pi', table.const.name)
+        table.const.name = 'POW'
+        self.assertEqual('POW', table.const.name)
+
+        table_const_name = self.lua.eval('function(t) return t.const.name end')
+        self.assertEqual('POW', table_const_name(table))
+
+    def test_setitem_table(self):
+        table = self.lua.eval('{ const={ name="Pi", value=3.1415927 }, const2={ name="light speed", value=3e8 }, val=1 }')
+
+        self.assertEqual(1, table.val)
+        table['val'] = 2
+        self.assertEqual(2, table.val)
+
+        get_val = self.lua.eval('function(t) return t.val end')
+        self.assertEqual(2, get_val(table))
+
+        self.assertEqual('Pi', table.const.name)
+        table['const']['name'] = 'POW'
+        self.assertEqual('POW', table.const.name)
+
+        get_table_const_name = self.lua.eval('function(t) return t.const.name end')
+        self.assertEqual('POW', get_table_const_name(table))
+
+    def test_globals(self):
+        lua_globals = self.lua.globals()
+        self.assertNotEqual(None, lua_globals.unpack)
+
+    def test_require(self):
+        stringlib = self.lua.require('string')
+        self.assertNotEqual(None, stringlib)
+        self.assertNotEqual(None, stringlib.char)
+
+    def test_libraries(self):
+        libraries = self.lua.eval('{require, table, io, os, math, string, debug, bit, jit}')
+        self.assertEqual(9, len(libraries))
+        self.assertTrue(None not in libraries)
+
     def test_callable_values(self):
         function = self.lua.eval('function(f) return f() + 5 end')
         def test():
@@ -346,7 +410,7 @@ class TestThreading(unittest.TestCase):
         return calc
         '''
         lua = lupa.LuaRuntime()
-        functions = [ lua.run(func_code) for _ in range(10) ]
+        functions = [ lua.execute(func_code) for _ in range(10) ]
         results = [None] * len(functions)
 
         def test(i, func, *args):
@@ -371,7 +435,7 @@ class TestThreading(unittest.TestCase):
         return calc
         '''
         runtimes  = [ lupa.LuaRuntime() for _ in range(10) ]
-        functions = [ lua.run(func_code) for lua in runtimes ]
+        functions = [ lua.execute(func_code) for lua in runtimes ]
 
         results = [None] * len(runtimes)
 
@@ -397,7 +461,7 @@ class TestThreading(unittest.TestCase):
         return calc
         '''
         runtimes  = [ lupa.LuaRuntime() for _ in range(10) ]
-        functions = [ lua.run(func_code) for lua in runtimes ]
+        functions = [ lua.execute(func_code) for lua in runtimes ]
 
         results = [None] * len(runtimes)
 
